@@ -33,6 +33,12 @@ public enum ShaderType {
 	 */
 	VERTEX_SHADER,
 
+	/**
+	 * ジオメトリシェーダ
+	 * @since 0.5.1
+	 */
+	GEOMETRY_SHADER,
+
 	/**
 	 * フラグメントシェーダ
 	 */
