@@ -23,11 +23,13 @@
 
 package ch.kuramo.javie.app;
 
+import java.io.File;
 import java.net.URL;
 
 import org.eclipse.core.runtime.FileLocator;
 import org.eclipse.core.runtime.IPath;
 import org.eclipse.core.runtime.Path;
+import org.eclipse.core.runtime.Platform;
 import org.eclipse.jface.resource.ColorRegistry;
 import org.eclipse.jface.resource.ImageDescriptor;
 import org.eclipse.jface.resource.ImageRegistry;
@@ -77,10 +79,19 @@ public class Activator extends AbstractUIPlugin {
 
 		Java2DFboBugFix.patch();
 		JsonicBugFix.patch();
+		SplashEnhancement.patch();
 		DragSourceEnhancement.patch();
 		DropTargetEnhancement.patch();
 		TreeViewerEditorEnhancement.patch();
 		ColorDialogBugFix.patch();
+		Java6Update26Detection.patch();
+
+
+		File logFile = Platform.getLogFileLocation().toFile();
+		if (logFile.exists()) {
+			String newName = String.format("%1$s-%2$tY%2$tm%2$td-%2$tH%2$tM%2$tS", logFile.getName(), logFile.lastModified());
+			logFile.renameTo(new File(logFile.getParentFile(), newName));
+		}
 	}
 
 	/*
@@ -177,6 +188,9 @@ public class Activator extends AbstractUIPlugin {
 	public static final String IMG_STOPWATCH_NO_KF	= "IMG_STOPWATCH_NO_KF";
 	public static final String IMG_STOPWATCH_HAS_KF	= "IMG_STOPWATCH_HAS_KF";
 
+	private static final boolean WIN32 = SWT.getPlatform().equals("win32");
+	private static final boolean COCOA = SWT.getPlatform().equals("cocoa");
+
 	protected void initializeImageRegistry(ImageRegistry reg) {
 		registerImage(reg, IMG_PLAYER_PLAY, "player_play.png");
 		registerImage(reg, IMG_PLAYER_PAUSE, "player_pause.png");
@@ -236,12 +250,20 @@ public class Activator extends AbstractUIPlugin {
 		registerImage(reg, IMG_SWITCH_LINK, "switch_link.png");
 		registerImage(reg, IMG_SWITCH_TINY_2D_MANIP, "switch_tiny_2d_manip.png");
 
-		registerImage(reg, IMG_KF_HOLD,        "kf_hold.png");
-		registerImage(reg, IMG_KF_HOLD_SELECT, "kf_hold_select.png");
-		registerImage(reg, IMG_KF_LINEAR,        "kf_linear.png");
-		registerImage(reg, IMG_KF_LINEAR_SELECT, "kf_linear_select.png");
-		registerImage(reg, IMG_KF_CATMULL_ROM,        "kf_catmull_rom.png");
-		registerImage(reg, IMG_KF_CATMULL_ROM_SELECT, "kf_catmull_rom_select.png");
+		if (WIN32) {
+			registerImage(reg, IMG_KF_HOLD, "kf_hold_win32.png");
+			registerImage(reg, IMG_KF_LINEAR, "kf_linear_win32.png");
+			registerImage(reg, IMG_KF_CATMULL_ROM, "kf_catmull_rom_win32.png");
+		} else if (COCOA) {
+			registerImage(reg, IMG_KF_HOLD,        "kf_hold_cocoa.png");
+			registerImage(reg, IMG_KF_HOLD_SELECT, "kf_hold_select_cocoa.png");
+			registerImage(reg, IMG_KF_LINEAR,        "kf_linear_cocoa.png");
+			registerImage(reg, IMG_KF_LINEAR_SELECT, "kf_linear_select_cocoa.png");
+			registerImage(reg, IMG_KF_CATMULL_ROM,        "kf_catmull_rom_cocoa.png");
+			registerImage(reg, IMG_KF_CATMULL_ROM_SELECT, "kf_catmull_rom_select_cocoa.png");
+		} else {
+			// FIXME
+		}
 
 		registerImage(reg, IMG_KFNAV_PREV,          "kfnav_prev.png");
 		registerImage(reg, IMG_KFNAV_PREV_DISABLED, "kfnav_prev_disabled.png");
@@ -273,6 +295,14 @@ public class Activator extends AbstractUIPlugin {
 	public static final String COLOR_SWITCH_BORDER_LIGHT_GRAY_TL	= "COLOR_SWITCH_BORDER_LIGHT_GRAY_TL";
 	public static final String COLOR_SWITCH_BORDER_LIGHT_GRAY_BR	= "COLOR_SWITCH_BORDER_LIGHT_GRAY_BR";
 
+	public static final String COLOR_LAYERBAR			= "COLOR_LAYERBAR";
+	public static final String COLOR_LAYER_EXCEEDED		= "COLOR_LAYER_EXCEEDED";
+	public static final String COLOR_LAYER_SLIPBAR		= "COLOR_LAYER_SLIPBAR";
+
+	public static final String COLOR_KEYFRAME			= "COLOR_KEYFRAME";
+	public static final String COLOR_KEYFRAME_SELECTED	= "COLOR_KEYFRAME_SELECTED";
+	public static final String COLOR_KEYFRAME_BORDER	= "COLOR_KEYFRAME_BORDER";
+
 
 	public ColorRegistry getColorRegistry() {
 		if (colorRegistry == null) {
@@ -307,6 +337,14 @@ public class Activator extends AbstractUIPlugin {
 		reg.put(COLOR_SWITCH_BORDER_COCOA_GRAY_BR, new RGB(240, 240, 240));
 		reg.put(COLOR_SWITCH_BORDER_LIGHT_GRAY_TL, new RGB(140, 140, 140));
 		reg.put(COLOR_SWITCH_BORDER_LIGHT_GRAY_BR, new RGB(212, 212, 212));
+
+		reg.put(COLOR_LAYERBAR, new RGB(158, 62, 62));
+		reg.put(COLOR_LAYER_EXCEEDED, new RGB(147, 83, 83));
+		reg.put(COLOR_LAYER_SLIPBAR, new RGB(189, 125, 125));
+
+		reg.put(COLOR_KEYFRAME, new RGB(161, 161, 161));
+		reg.put(COLOR_KEYFRAME_SELECTED, new RGB(255, 205, 71));
+		reg.put(COLOR_KEYFRAME_BORDER, new RGB(36, 36, 36));
 	}
 
 }
