@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009,2010 Yoshikazu Kuramochi
+ * Copyright (c) 2009-2011 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -27,9 +27,11 @@ import ch.kuramo.javie.api.Size2i;
 import ch.kuramo.javie.api.Vec3d;
 import ch.kuramo.javie.app.InjectorHolder;
 import ch.kuramo.javie.core.LayerComposition;
+import ch.kuramo.javie.core.LayerNature;
 import ch.kuramo.javie.core.TextLayer;
 import ch.kuramo.javie.core.services.Font;
 import ch.kuramo.javie.core.services.FontList;
+import ch.kuramo.javie.core.services.GLGlobal;
 import ch.kuramo.javie.core.services.ProjectElementFactory;
 
 import com.google.inject.Inject;
@@ -39,6 +41,9 @@ public class NewTextLayerOperation extends AbstractNewLayerOperation<TextLayer>
 	@Inject
 	private FontList _fontList;
 
+	@Inject
+	private GLGlobal _glGlobal;
+
 
 	public NewTextLayerOperation(ProjectManager projectManager, LayerComposition comp) {
 		super(projectManager, comp, "新規テキスト");
@@ -61,6 +66,10 @@ public class NewTextLayerOperation extends AbstractNewLayerOperation<TextLayer>
 		Vec3d compCenter = new Vec3d(compSize.width/2d, compSize.height/2d);
 		layer.getPosition().reset(compCenter);
 
+		if (_glGlobal.getMaxSamples() > 0) {
+			LayerNature.setCTCR(layer, true);
+		}
+
 		return layer;
 	}
 
