@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009,2010 Yoshikazu Kuramochi
+ * Copyright (c) 2009-2011 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -364,6 +364,30 @@ public class ProjectManager implements IOperationHistoryListener {
 		fireProjectEvent(ProjectEvent.createLayersReorderEvent(this, comp, layers));
 	}
 
+	void fireTextAnimatorsAdd(LayerComposition comp, Object[][] data) {
+		fireProjectEvent(ProjectEvent.createTextAnimatorsAddEvent(this, comp, data));
+	}
+
+	void fireTextAnimatorsRemove(LayerComposition comp, Object[][] data) {
+		fireProjectEvent(ProjectEvent.createTextAnimatorsRemoveEvent(this, comp, data));
+	}
+
+	void fireTASelectorsAdd(LayerComposition comp, Object[][] data) {
+		fireProjectEvent(ProjectEvent.createTASelectorsAddEvent(this, comp, data));
+	}
+
+	void fireTASelectorsRemove(LayerComposition comp, Object[][] data) {
+		fireProjectEvent(ProjectEvent.createTASelectorsRemoveEvent(this, comp, data));
+	}
+
+	void fireTAPropertiesAdd(LayerComposition comp, Object[][] data) {
+		fireProjectEvent(ProjectEvent.createTAPropertiesAddEvent(this, comp, data));
+	}
+
+	void fireTAPropertiesRemove(LayerComposition comp, Object[][] data) {
+		fireProjectEvent(ProjectEvent.createTAPropertiesRemoveEvent(this, comp, data));
+	}
+
 	void fireEffectPropertyChange(EffectableLayer layer, int effectIndex, String property) {
 		fireProjectEvent(ProjectEvent.createEffectPropertyChangeEvent(this, layer, effectIndex, property));
 	}
@@ -760,7 +784,7 @@ class ShadowOperationRunner extends Thread {
 
 	@Override
 	public void run() {
-		Set<Runnable> drain = Util.newSet();
+		List<Runnable> drain = Util.newList();
 		for (;;) {
 			drain.clear();
 
