@@ -25,6 +25,7 @@ package ch.kuramo.javie.app.project;
 
 import java.util.Iterator;
 import java.util.List;
+import java.util.Set;
 
 import org.eclipse.core.commands.ExecutionException;
 import org.eclipse.core.runtime.IAdaptable;
@@ -33,7 +34,6 @@ import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.Status;
 
 import ch.kuramo.javie.api.Time;
-import ch.kuramo.javie.app.InjectorHolder;
 import ch.kuramo.javie.app.PropertyUtil;
 import ch.kuramo.javie.core.AnimatableValue;
 import ch.kuramo.javie.core.Effect;
@@ -43,25 +43,43 @@ import ch.kuramo.javie.core.Keyframe;
 import ch.kuramo.javie.core.Layer;
 import ch.kuramo.javie.core.LayerComposition;
 import ch.kuramo.javie.core.Project;
-import ch.kuramo.javie.core.ProjectDecodeException;
 import ch.kuramo.javie.core.PropertyDescriptor;
 import ch.kuramo.javie.core.Util;
-import ch.kuramo.javie.core.services.ProjectDecoder;
-import ch.kuramo.javie.core.services.ProjectEncoder;
-
-import com.google.inject.Inject;
 
 public class ShiftLayerTimesOperation extends ProjectOperation {
 
 	private static class Entry {
 		final String layerId;
-		final Time[] oldTimes;
-		final List<String> oldAvalues = Util.newList();
+		final Time startTime;
+		final Time inPoint;
+		final Time outPoint;
+		final List<Set<Keyframe<?>>> keyframes = Util.newList();
 
-		public Entry(String layerId, Time[] oldTimes) {
-			super();
-			this.layerId = layerId;
-			this.oldTimes = oldTimes;
+		Entry(Layer layer) {
+			layerId = layer.getId();
+			startTime = layer.getStartTime();
+			inPoint = layer.getInPoint();
+			outPoint = layer.getOutPoint();
+
+			for (String property : PropertyUtil.getLayerPropertyNames(layer)) {
+				Object o = PropertyUtil.getProperty(layer, property);
+				if (o instanceof AnimatableValue<?>) {
+					AnimatableValue<?> avalue = (AnimatableValue<?>) o;
+					keyframes.add(Util.<Keyframe<?>>newSet(avalue.getKeyframeMap().values()));
+				}
+			}
+
+			if (layer instanceof EffectableLayer) {
+				for (Effect effect : ((EffectableLayer) layer).getEffects()) {
+					for (PropertyDescriptor pd : effect.getEffectDescriptor().getPropertyDescriptors()) {
+						Object o = pd.get(effect);
+						if (o instanceof AnimatableValue<?>) {
+							AnimatableValue<?> avalue = (AnimatableValue<?>) o;
+							keyframes.add(Util.<Keyframe<?>>newSet(avalue.getKeyframeMap().values()));
+						}
+					}
+				}
+			}
 		}
 	}
 
@@ -72,18 +90,12 @@ public class ShiftLayerTimesOperation extends ProjectOperation {
 
 	private volatile Time _deltaTime;
 
-	@Inject
-	private ProjectEncoder _encoder;
-
-	@Inject
-	private ProjectDecoder _decoder;
-
 
 	public ShiftLayerTimesOperation(
-			ProjectManager projectManager, LayerComposition comp, List<Layer> layers, Time deltaTime, String relation) {
+			ProjectManager projectManager, LayerComposition comp,
+			List<Layer> layers, Time deltaTime, String relation) {
 
 		super(projectManager, "レイヤー時間の変更", relation);
-		InjectorHolder.getInjector().injectMembers(this);
 
 		projectManager.checkComposition(comp);
 		_compId = comp.getId();
@@ -93,59 +105,7 @@ public class ShiftLayerTimesOperation extends ProjectOperation {
 			if (projectManager.checkLayer(layer) != comp) {
 				throw new IllegalArgumentException();
 			}
-
-			Entry e = new Entry(layer.getId(),
-					new Time[] { layer.getStartTime(), layer.getInPoint(), layer.getOutPoint() });
-
-			for (String property : PropertyUtil.getLayerPropertyNames(layer)) {
-				Object o = PropertyUtil.getProperty(layer, property);
-				if (o instanceof AnimatableValue<?>) {
-					e.oldAvalues.add(_encoder.encodeElement(o));
-				}
-			}
-
-			if (layer instanceof EffectableLayer) {
-				for (Effect effect : ((EffectableLayer) layer).getEffects()) {
-					for (PropertyDescriptor pd : effect.getEffectDescriptor().getPropertyDescriptors()) {
-						Object o = pd.get(effect);
-						if (o instanceof AnimatableValue<?>) {
-							e.oldAvalues.add(_encoder.encodeElement(o));
-						}
-					}
-				}
-			}
-
-			_entries.add(e);
-		}
-	}
-
-	private <V> void shiftKeyframes(AnimatableValue<V> avalue) {
-		List<Keyframe<V>> list = Util.newList();
-		for (Keyframe<V> kf : avalue.getKeyframeMap().values()) {
-			list.add(new Keyframe<V>(_deltaTime.add(kf.time), kf.value, kf.interpolation));
-		}
-
-		avalue.clearKeyframes(avalue.getStaticValue());
-		for (Keyframe<V> kf : list) {
-			avalue.putKeyframe(kf);
-		}
-	}
-
-	// TODO ThreeDSwitchOperation 等にほぼ同じメソッドがあるので整理する。
-	private <A extends AnimatableValue<V>, V> void restore(String data, A dst) throws ExecutionException {
-		try {
-			@SuppressWarnings("unchecked")
-			A src = _decoder.decodeElement(data, (Class<A>) dst.getClass());
-
-			dst.reset(src.getStaticValue());
-			dst.setExpression(src.getExpression());
-
-			for (Keyframe<V> kf : src.getKeyframeMap().values()) {
-				dst.putKeyframe(kf);
-			}
-
-		} catch (ProjectDecodeException e) {
-			throw new ExecutionException("error decoding AnimatableValue data", e);
+			_entries.add(new Entry(layer));
 		}
 	}
 
@@ -153,46 +113,7 @@ public class ShiftLayerTimesOperation extends ProjectOperation {
 	protected IStatus executeOrRedo(IProgressMonitor monitor, IAdaptable info,
 			Project project, ProjectManager pm) throws ExecutionException {
 
-		LayerComposition comp = project.getComposition(_compId);
-		List<Layer> layers = Util.newList();
-
-		for (Entry e : _entries) {
-			Layer layer = comp.getLayer(e.layerId);
-			layer.setStartTime(_deltaTime.add(e.oldTimes[0]));
-			layer.setInPoint(_deltaTime.add(e.oldTimes[1]));
-			layer.setOutPoint(_deltaTime.add(e.oldTimes[2]));
-
-			Iterator<String> it = e.oldAvalues.iterator();
-
-			for (String property : PropertyUtil.getLayerPropertyNames(layer)) {
-				Object o = PropertyUtil.getProperty(layer, property);
-				if (o instanceof AnimatableValue<?>) {
-					AnimatableValue<?> avalue = (AnimatableValue<?>) o;
-					restore(it.next(), avalue);
-					shiftKeyframes(avalue);
-				}
-			}
-
-			if (layer instanceof EffectableLayer) {
-				for (Effect effect : ((EffectableLayer) layer).getEffects()) {
-					for (PropertyDescriptor pd : effect.getEffectDescriptor().getPropertyDescriptors()) {
-						Object o = pd.get(effect);
-						if (o instanceof AnimatableValue<?>) {
-							AnimatableValue<?> avalue = (AnimatableValue<?>) o;
-							restore(it.next(), avalue);
-							shiftKeyframes(avalue);
-						}
-					}
-				}
-			}
-
-			layers.add(layer);
-		}
-
-		if (pm != null) {
-			pm.fireLayerTimesChange(comp, layers);
-		}
-
+		shiftOrRestore(true, project, pm);
 		return Status.OK_STATUS;
 	}
 
@@ -200,21 +121,34 @@ public class ShiftLayerTimesOperation extends ProjectOperation {
 	protected IStatus undo(IProgressMonitor monitor, IAdaptable info,
 			Project project, ProjectManager pm) throws ExecutionException {
 
+		shiftOrRestore(false, project, pm);
+		return Status.OK_STATUS;
+	}
+
+	private void shiftOrRestore(boolean shift, Project project, ProjectManager pm) throws ExecutionException {
 		LayerComposition comp = project.getComposition(_compId);
 		List<Layer> layers = Util.newList();
 
 		for (Entry e : _entries) {
 			Layer layer = comp.getLayer(e.layerId);
-			layer.setStartTime(e.oldTimes[0]);
-			layer.setInPoint(e.oldTimes[1]);
-			layer.setOutPoint(e.oldTimes[2]);
+			layer.setStartTime(shift ? _deltaTime.add(e.startTime) : e.startTime);
+			layer.setInPoint(shift ? _deltaTime.add(e.inPoint) : e.inPoint);
+			layer.setOutPoint(shift ? _deltaTime.add(e.outPoint) : e.outPoint);
 
-			Iterator<String> it = e.oldAvalues.iterator();
+			Iterator<?> it = e.keyframes.iterator();
 
 			for (String property : PropertyUtil.getLayerPropertyNames(layer)) {
 				Object o = PropertyUtil.getProperty(layer, property);
 				if (o instanceof AnimatableValue<?>) {
-					restore(it.next(), (AnimatableValue<?>) o);
+					@SuppressWarnings("unchecked")
+					AnimatableValue<Object> avalue = (AnimatableValue<Object>) o;
+					@SuppressWarnings("unchecked")
+					Set<Keyframe<Object>> origKeyframes = (Set<Keyframe<Object>>) it.next();
+					if (shift) {
+						shiftKeyframes(avalue, origKeyframes);
+					} else {
+						restore(avalue, origKeyframes);
+					}
 				}
 			}
 
@@ -223,7 +157,15 @@ public class ShiftLayerTimesOperation extends ProjectOperation {
 					for (PropertyDescriptor pd : effect.getEffectDescriptor().getPropertyDescriptors()) {
 						Object o = pd.get(effect);
 						if (o instanceof AnimatableValue<?>) {
-							restore(it.next(), (AnimatableValue<?>) o);
+							@SuppressWarnings("unchecked")
+							AnimatableValue<Object> avalue = (AnimatableValue<Object>) o;
+							@SuppressWarnings("unchecked")
+							Set<Keyframe<Object>> origKeyframes = (Set<Keyframe<Object>>) it.next();
+							if (shift) {
+								shiftKeyframes(avalue, origKeyframes);
+							} else {
+								restore(avalue, origKeyframes);
+							}
 						}
 					}
 				}
@@ -235,8 +177,20 @@ public class ShiftLayerTimesOperation extends ProjectOperation {
 		if (pm != null) {
 			pm.fireLayerTimesChange(comp, layers);
 		}
+	}
 
-		return Status.OK_STATUS;
+	private <V> void shiftKeyframes(AnimatableValue<V> avalue, Set<Keyframe<V>> origKeyframes) {
+		avalue.clearKeyframes(avalue.getStaticValue());
+		for (Keyframe<V> kf : origKeyframes) {
+			avalue.putKeyframe(new Keyframe<V>(_deltaTime.add(kf.time), kf.value, kf.interpolation));
+		}
+	}
+
+	private <V> void restore(AnimatableValue<V> avalue, Set<Keyframe<V>> origKeyframes) {
+		avalue.clearKeyframes(avalue.getStaticValue());
+		for (Keyframe<V> kf : origKeyframes) {
+			avalue.putKeyframe(kf);
+		}
 	}
 
 	@Override
@@ -252,31 +206,20 @@ public class ShiftLayerTimesOperation extends ProjectOperation {
 			return true;
 		}
 
-		if (!(operation instanceof ShiftLayerTimesOperation)) {
-			return false;
-		}
-
 		ShiftLayerTimesOperation newOp = (ShiftLayerTimesOperation) operation;
-		if (!newOp._compId.equals(_compId) || newOp._entries.size() != _entries.size()) {
-			return false;
-		}
 
-		for (int i = 0, n = _entries.size(); i < n; ++i) {
-			if (!newOp._entries.get(i).layerId.equals(_entries.get(i).layerId)) {
-				return false;
+		if (!newOp._deltaTime.equals(_deltaTime)) {
+			_deltaTime = newOp._deltaTime;
+
+			try {
+				executeOrRedo(monitor, info, project, pm);
+			} catch (ExecutionException e) {
+				throw new JavieRuntimeException(e);
 			}
+
+			_noEffect = (_deltaTime.timeValue == 0);
 		}
 
-		_deltaTime = newOp._deltaTime;
-
-		try {
-			executeOrRedo(monitor, info, project, pm);
-		} catch (ExecutionException e) {
-			throw new JavieRuntimeException(e);
-		}
-
-		_noEffect = (_deltaTime.timeValue == 0);
-
 		return true;
 	}
 
