@@ -79,7 +79,7 @@ public class AnimatableDoubleElementDelegate extends AnimatableValueElementDeleg
 
 	protected void drawValue(GC gc, int x, int y, int height, boolean focused) {
 		if (editor == null) {
-			drawValue(gc, x, y, height, focused, value, displayPrecision, unit);
+			drawValue(gc, x, y, height, focused, valueToDraw, displayPrecision, unit);
 		}
 	}
 
@@ -91,6 +91,10 @@ public class AnimatableDoubleElementDelegate extends AnimatableValueElementDeleg
 		return originalValue + increment * dx;
 	}
 
+	protected boolean isInPlaceEditorActive() {
+		return (editor != null);
+	}
+
 	public boolean canEdit(int columnIndex) {
 		if (columnIndex == LayerCompositionView.VALUE_COL) {
 			return canInPlaceEdit;
@@ -110,13 +114,13 @@ public class AnimatableDoubleElementDelegate extends AnimatableValueElementDeleg
 
 	public Object getCellEditorValue(int columnIndex) {
 		if (columnIndex == LayerCompositionView.VALUE_COL) {
-			return formatValue(value, editorPrecision);
+			return formatValue(valueWithoutExpr, editorPrecision);
 		}
 		return null;
 	}
 
 	public void setCellEditorValue(int columnIndex, Object value) {
-		if (columnIndex == LayerCompositionView.VALUE_COL && !value.equals(formatValue(this.value, editorPrecision))) {
+		if (columnIndex == LayerCompositionView.VALUE_COL && !value.equals(formatValue(valueWithoutExpr, editorPrecision))) {
 			try {
 				modifyValue(Double.valueOf((String) value));
 			} catch (NumberFormatException e) {
