@@ -44,7 +44,7 @@ public class AnimatableStringElementDelegate extends AnimatableValueElementDeleg
 	}
 
 	protected void drawValue(GC gc, int x, int y, int height, boolean focused) {
-		drawValue(gc, x, y, height, focused, (value.length() > 0) ? value : "      ");
+		drawValue(gc, x, y, height, focused, (valueToDraw.length() > 0) ? valueToDraw : "      ");
 	}
 
 	protected boolean canDragGestureEdit() {
@@ -55,6 +55,11 @@ public class AnimatableStringElementDelegate extends AnimatableValueElementDeleg
 		throw new UnsupportedOperationException("drag gesture edit is not supported");
 	}
 
+	protected boolean isInPlaceEditorActive() {
+		// FIXME TextCellEditorがアクティブな時は true を返すべき。
+		return false;
+	}
+
 	public boolean canEdit(int columnIndex) {
 		if (columnIndex == LayerCompositionView.VALUE_COL) {
 			return canInPlaceEdit;
@@ -78,7 +83,7 @@ public class AnimatableStringElementDelegate extends AnimatableValueElementDeleg
 
 	public Object getCellEditorValue(int columnIndex) {
 		if (columnIndex == LayerCompositionView.VALUE_COL) {
-			return value;
+			return valueWithoutExpr;
 		}
 		return null;
 	}
