@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009,2010 Yoshikazu Kuramochi
+ * Copyright (c) 2009-2011 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -24,7 +24,6 @@
 package ch.kuramo.javie.app.views.layercomp;
 
 import ch.kuramo.javie.app.views.LayerCompositionView;
-import ch.kuramo.javie.core.Layer;
 import ch.kuramo.javie.core.TextLayer;
 
 public class TextElement extends Element {
@@ -54,17 +53,21 @@ public class TextElement extends Element {
 	@Override
 	public Element[] getChildren() {
 		if (children == null) {
-			Layer layer = ((LayerElement) parent).layer;
+			TextLayer layer = getLayer();
 			children = new Element[] {
-					new TextSourceElement(this, (TextLayer) layer),
-					new TextFontElement(this, (TextLayer) layer),
-					new LayerAnimatableValueElement(this, layer, "fontSize", "フォントサイズ", "px"),
-					new LayerAnimatableValueElement(this, layer, "fillColor", "塗りのカラー"),
-					new LayerAnimatableValueElement(this, layer, "horizontalAlignment", "整列"),
-					new TextLeadingElement(this, (TextLayer) layer)
+					new TextSourceElement(this, layer),
+					new TextFontElement(this, layer),
+					LayerAnimatableValueElement.forSimpleProperty(this, layer, "fontSize", "フォントサイズ", "px"),
+					new TextTypeElement(this),
+					new TextOptionsElement(this),
+					new TextAnimatorsElement(this)
 			};
 		}
 		return children;
 	}
 
+	TextLayer getLayer() {
+		return (TextLayer) ((LayerElement) parent).layer;
+	}
+
 }
