@@ -571,14 +571,17 @@ public class TimelineManager {
 		if (x1-3 < x && x < x1+3) {
 			clearKeyframeSelection();
 			dragGestureEditor = new DragGestureInPointShifter(e, layer, pixelsToTime(x, frameDuration, zoom));
+			return;
 
 		} else if (x2-3 < x && x < x2+3) {
 			clearKeyframeSelection();
 			dragGestureEditor = new DragGestureOutPointShifter(e, layer, pixelsToTime(x, frameDuration, zoom));
+			return;
 
 		} else if (x1 <= x && x < x2) {
 			clearKeyframeSelection();
 			dragGestureEditor = new DragGestureLayerTimeShifter(e, layer, pixelsToTime(x, frameDuration, zoom));
+			return;
 
 		} else if (layer instanceof MediaItemLayer && !LayerNature.isTimeRemapEnabled(layer)) {
 			MediaInput input = ((MediaItemLayer) layer).getMediaInput();
@@ -593,15 +596,18 @@ public class TimelineManager {
 
 					if (x1 <= x && x < x2) {
 						dragGestureEditor = new DragGestureSlipEditor(e, layer, pixelsToTime(x, frameDuration, zoom));
+						return;
 					}
 				}
 			}
-			if (dragGestureEditor == null) {
-				clearKeyframeSelection();			
-			}
-		} else {
-			clearKeyframeSelection();			
 		}
+
+		boolean add = (e.stateMask & SWT.MOD2) != 0;
+		boolean remove = (e.stateMask & SWT.MOD1) != 0;
+		if (!add && !remove) {
+			clearKeyframeSelection();
+		}
+		new DragGestureKeyframeSelector(e, remove);
 	}
 
 	public int drawKeyframes(Event e, AnimatableValue<?> avalue) {
@@ -686,8 +692,12 @@ public class TimelineManager {
 
 		Keyframe<?> kf = findKeyframe(e, yKeyframe, avalue);
 		if (kf == null) {
-			if (keyframeSelection.isEmpty()) return;
-			keyframeSelection.clear();
+			boolean add = (e.stateMask & SWT.MOD2) != 0;
+			boolean remove = (e.stateMask & SWT.MOD1) != 0;
+			if (!add && !remove) {
+				keyframeSelection.clear();
+			}
+			new DragGestureKeyframeSelector(e, remove);
 
 		} else if (!keyframeSelection.containsKey(kf)) {
 			if ((e.stateMask & SWT.SHIFT) != SWT.SHIFT) {
@@ -711,19 +721,25 @@ public class TimelineManager {
 	}
 
 	public void mouseDown(MouseEvent e) {
-		if (keyframeSelection.size() > 0 && e.x >= timelineColumnX()) {
+		boolean add = (e.stateMask & SWT.MOD2) != 0;
+		boolean remove = (e.stateMask & SWT.MOD1) != 0;
+		if (!add && !remove) {
 			clearKeyframeSelection();
-			redraw();
+		}
+		if (e.x >= timelineColumnX()) {
+			new DragGestureKeyframeSelector(e, remove);
 		}
 	}
 
 	public void clearKeyframeSelection() {
 		keyframeSelection.clear();
+		redraw();
 		view.updateDeleteActionState();
 	}
 
 	public void addKeyframeSelection(Keyframe<?> keyframe, AnimatableValueElement element) {
 		keyframeSelection.put(keyframe, element);
+		redraw();
 		view.updateDeleteActionState();
 	}
 
@@ -1232,4 +1248,190 @@ public class TimelineManager {
 
 	}
 
+	private class DragGestureKeyframeSelector implements Listener, PaintListener, Runnable {
+
+		private final long downTime;
+
+		private final boolean removeMode;
+
+		private final Map<Keyframe<?>, AnimatableValueElement> origSelection;
+
+		private final Display display;
+
+		private final Tree tree;
+
+		private final Rectangle clientArea;
+
+		private final int timelineColumnX;
+
+		private int scroll;
+
+		private final Time frameDuration;
+
+		private final Time downXasTime;
+
+		private final int downY;
+
+		private Rectangle rect;
+
+		private Point currPt;
+
+		private boolean dragDetected;
+
+		private DragGestureKeyframeSelector(MouseEvent event, boolean remove) {
+			downTime = System.currentTimeMillis();
+			removeMode = remove;
+			origSelection = Util.newMap(keyframeSelection);
+
+			display = event.display;
+			tree = timelineColumn.getParent();
+			clientArea = tree.getClientArea();
+
+			timelineColumnX = timelineColumnX();
+			scroll = scrollSlider.getSelection();
+			frameDuration = composition.getFrameDuration();
+
+			int x = event.x - timelineColumnX + scroll;
+			downXasTime = pixelsToTime(x, frameDuration, zoom);
+			downY = event.y;
+			rect = new Rectangle(event.x, event.y, 0, 0);
+
+			display.addFilter(SWT.MouseMove, this);
+			display.addFilter(SWT.MouseUp, this);
+			display.addFilter(SWT.Deactivate, this);
+		}
+
+		public void handleEvent(Event e) {
+			switch (e.type) {
+				case SWT.MouseMove:
+					if (!tree.isDisposed()) {
+						if (COCOA && (getCocoaCurrentButtonState() & 1) == 0) {
+							break;
+						}
+
+						currPt = tree.toControl(display.getCursorLocation());
+
+						int downX = timeToPixels(downXasTime, frameDuration, zoom)
+										+ timelineColumnX - scrollSlider.getSelection();
+
+						if (!dragDetected) {
+							dragDetected = (System.currentTimeMillis() - downTime > 100)
+											&& (Math.abs(currPt.x - downX) > 3 || Math.abs(currPt.y - downY) > 3);
+							if (dragDetected) {
+								tree.addPaintListener(this);
+								display.timerExec(100, this);
+							}
+						}
+
+						if (dragDetected) {
+							update(downX);
+						}
+
+						break;
+					}
+					// fall through
+
+				case SWT.MouseUp:
+				case SWT.Deactivate:
+					dragDetected = false;
+					display.removeFilter(SWT.MouseMove, this);
+					display.removeFilter(SWT.MouseUp, this);
+					display.removeFilter(SWT.Deactivate, this);
+					tree.removePaintListener(this);
+					if (COCOA) {
+						// Macの場合、タイムラインの横線が消えてしまうので、以下はその対策。
+						int y = Math.min(rect.y, clientArea.y);
+						int h = Math.max(0, rect.y-clientArea.y) + rect.height;
+						tree.redraw(rect.x-5, y, rect.width+10, h+5, true);
+					} else {
+						tree.redraw(rect.x-5, rect.y-5, rect.width+10, rect.height+10, true);
+					}
+					break;
+			}
+		}
+
+		public void paintControl(PaintEvent e) {
+			if (!rect.isEmpty()) {
+				e.gc.setClipping(clientArea.x+timelineColumnX, clientArea.y,
+						clientArea.width-timelineColumnX, clientArea.height);
+				if (COCOA) {
+					e.gc.setBackground(e.display.getSystemColor(SWT.COLOR_BLACK));
+					e.gc.setAlpha(52);
+					e.gc.fillRectangle(rect.x, rect.y, rect.width, rect.height);
+					e.gc.setAlpha(255);
+				} else {
+					e.gc.setForeground(e.display.getSystemColor(SWT.COLOR_BLACK));
+					e.gc.setLineWidth(2);
+					e.gc.drawRectangle(rect.x+1, rect.y+1, rect.width-2, rect.height-2);
+				}
+			}
+		}
+
+		public void run() {
+			if (dragDetected && !scrollSlider.isDisposed()) {
+				int newScroll = scrollSlider.getSelection();
+				if (newScroll != scroll) {
+					scroll = newScroll;
+					int downX = timeToPixels(downXasTime, frameDuration, zoom) + timelineColumnX - scroll;
+					update(downX);
+				}
+				display.timerExec(100, this);
+			}
+		}
+
+		private void update(int downX) {
+			final Rectangle newRect = new Rectangle(
+					Math.min(downX, currPt.x), Math.min(downY, currPt.y),
+					Math.abs(downX - currPt.x), Math.abs(downY - currPt.y));
+
+			final Time time1 = pixelsToTime(newRect.x-timelineColumnX+scroll, frameDuration, zoom);
+			final Time time2 = pixelsToTime(newRect.x+newRect.width-timelineColumnX+scroll, frameDuration, zoom);
+			final Map<Keyframe<?>, AnimatableValueElement> keyframesInNewRect = Util.newMap();
+			new Object() {
+				void collectKeyframesInNewRect(TreeItem[] items) {
+					for (TreeItem item : items) {
+						Object data = item.getData();
+						if (data instanceof AnimatableValueElement) {
+							Rectangle b = item.getBounds(LayerCompositionView.TIMELINE_COL);
+							int y = b.y + b.height/2;
+							if (y >= newRect.y && y < newRect.y+newRect.height) {
+								AnimatableValueElement element = (AnimatableValueElement) data;
+
+								@SuppressWarnings("unchecked")
+								AnimatableValue<Object> avalue = (AnimatableValue<Object>) element.getAnimatableValue();
+
+								for (Keyframe<?> kf : avalue.getKeyframeMap().subMap(time1, time2).values()) {
+									keyframesInNewRect.put(kf, element);
+								}
+							}
+						}
+						if (item.getExpanded()) {
+							collectKeyframesInNewRect(item.getItems());
+						}
+					}
+				}
+			}.collectKeyframesInNewRect(tree.getItems());
+
+			keyframeSelection.clear();
+			keyframeSelection.putAll(origSelection);
+			if (removeMode) {
+				keyframeSelection.keySet().removeAll(keyframesInNewRect.keySet());
+			} else {
+				keyframeSelection.putAll(keyframesInNewRect);
+			}
+
+			Rectangle redraw = newRect.union(rect);
+			rect = newRect;
+			if (COCOA) {
+				// Macの場合、タイムラインの横線が消えてしまうので、以下はその対策。
+				int y = Math.min(redraw.y, clientArea.y);
+				int h = Math.max(0, redraw.y-clientArea.y) + redraw.height;
+				tree.redraw(redraw.x-5, y, redraw.width+10, h+5, true);
+			} else {
+				tree.redraw(redraw.x-5, redraw.y-5, redraw.width+10, redraw.height+10, true);
+			}
+		}
+
+	}
+
 }
