@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010 Yoshikazu Kuramochi
+ * Copyright (c) 2010,2011 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -23,6 +23,7 @@
 
 package ch.kuramo.javie.app.wizards;
 
+import java.io.File;
 import java.lang.reflect.Field;
 import java.util.Arrays;
 import java.util.Collections;
@@ -32,6 +33,7 @@ import java.util.Map;
 
 import org.eclipse.jface.dialogs.Dialog;
 import org.eclipse.jface.dialogs.IDialogConstants;
+import org.eclipse.jface.dialogs.IMessageProvider;
 import org.eclipse.jface.wizard.WizardPage;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.ModifyEvent;
@@ -49,6 +51,7 @@ import org.eclipse.swt.widgets.ColorDialog;
 import org.eclipse.swt.widgets.Combo;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Control;
+import org.eclipse.swt.widgets.FileDialog;
 import org.eclipse.swt.widgets.Group;
 import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
@@ -56,6 +59,7 @@ import org.eclipse.swt.widgets.Text;
 
 import ch.kuramo.javie.api.AudioMode;
 import ch.kuramo.javie.api.Color;
+import ch.kuramo.javie.app.BatchStore;
 import ch.kuramo.javie.app.widgets.GridBuilder;
 import ch.kuramo.javie.core.Composition;
 import ch.kuramo.javie.core.JavieRuntimeException;
@@ -70,6 +74,8 @@ public class AVIOutputSettingsWizardPage extends WizardPage {
 	private static final VideoCompressorDescriptor VIDEOCOMPDESC_UNCOMPRESSED
 							= VideoCompressorDescriptor.uncompressedDescriptor("非圧縮");
 
+	private static boolean batchDefault = false;
+
 	private static boolean videoEnabledDefault = true;
 
 	private static VideoChannels videoChannelsDefault = VideoChannels.RGB;
@@ -86,6 +92,12 @@ public class AVIOutputSettingsWizardPage extends WizardPage {
 
 	private final Composition composition;
 
+	private File defaultFile;
+
+	private File file;
+
+	private boolean batch = batchDefault;
+
 	private boolean videoEnabled = videoEnabledDefault;
 
 	private VideoChannels videoChannels = videoChannelsDefault;
@@ -101,11 +113,12 @@ public class AVIOutputSettingsWizardPage extends WizardPage {
 	private Image colorMatteImage;
 
 
-	public AVIOutputSettingsWizardPage(Composition composition) {
+	public AVIOutputSettingsWizardPage(Composition composition, File defaultFile) {
 		super("AVIOutputSettingsWizardPage");
 		setTitle("出力設定");
 
 		this.composition = composition;
+		this.defaultFile = defaultFile;
 	}
 
 	public void dispose() {
@@ -120,6 +133,8 @@ public class AVIOutputSettingsWizardPage extends WizardPage {
 		GridBuilder gb = new GridBuilder(parent, 1, false);
 		((GridLayout) gb.getComposite().getLayout()).verticalSpacing = 0;
 
+		createFileGroup(gb);
+		gb.size(15, 15).composite(SWT.NULL);
 		createVideoGroup(gb);
 		gb.size(15, 15).composite(SWT.NULL);
 		createAudioGroup(gb);
@@ -131,6 +146,48 @@ public class AVIOutputSettingsWizardPage extends WizardPage {
 		doValidate();
 	}
 
+	private void createFileGroup(GridBuilder gb) {
+		Group group = gb.hAlign(SWT.FILL).group(SWT.NONE, null);
+		group.setLayout(new FillLayout(SWT.HORIZONTAL));
+		GridBuilder gb2 = new GridBuilder(group, 3, false);
+		GridLayout layout = (GridLayout) gb2.getComposite().getLayout();
+		layout.marginWidth = 15;
+
+								gb2.hSpan(1).hAlign(SWT.RIGHT).label(SWT.NULL, "出力ファイル:");
+		final Text fileText =	gb2.hSpan(2).hAlign(SWT.FILL).hGrab().text(SWT.READ_ONLY, "");
+
+								gb2.hSpan(1).size(10, 10).composite(SWT.NULL);
+		Button batchCheck =		gb2.hSpan(1).hAlign(SWT.LEFT).button(SWT.CHECK, "バッチ登録");
+		Button fileButton =		gb2.hSpan(1).hAlign(SWT.RIGHT).tabBefore(batchCheck).button(SWT.PUSH, "ファイルを指定...");
+
+		fileText.setBackground(fileText.getDisplay().getSystemColor(SWT.COLOR_WHITE));
+
+		batchCheck.setSelection(batch);
+		batchCheck.addSelectionListener(new SelectionAdapter() {
+			public void widgetSelected(SelectionEvent e) {
+				batch = ((Button)e.widget).getSelection();
+				doValidate();
+			}
+		});
+
+		fileButton.setFocus();
+		fileButton.addSelectionListener(new SelectionAdapter() {
+			public void widgetSelected(SelectionEvent e) {
+				File newFile = showSaveDialog(defaultFile.getParentFile(), defaultFile.getName());
+				if (newFile != null) {
+					defaultFile = file = newFile;
+					fileText.setText(newFile.getAbsolutePath());
+					fileText.setFocus();
+					fileText.selectAll();
+					doValidate();
+				}
+			}
+		});
+
+		Composite grid2 = gb2.getComposite();
+		grid2.setTabList(gb2.getTabList());
+	}
+
 	private void createVideoGroup(GridBuilder gb) {
 		String[] channelItems = {
 				"RGB", "アルファ", "RGB + アルファ（ストレート）", "RGB + アルファ（乗算済み）"
@@ -253,6 +310,26 @@ public class AVIOutputSettingsWizardPage extends WizardPage {
 		grid3.setTabList(gb3.getTabList());
 	}
 
+	private File showSaveDialog(File folder, String fileName) {
+		String[] filterNames = new String[] { "AVI ファイル", "すべてのファイル" };
+		String[] filterExtensions = new String[] { "*.avi", "*" };
+
+		String platform = SWT.getPlatform();
+		if (platform.equals("win32") || platform.equals("wpf")) {
+			filterExtensions[filterExtensions.length-1] = "*.*";
+		}
+
+		FileDialog dialog = new FileDialog(getShell(), SWT.SAVE | SWT.SHEET);
+		dialog.setFilterNames(filterNames);
+		dialog.setFilterExtensions(filterExtensions);
+		dialog.setFilterPath(folder != null ? folder.getAbsolutePath() : null);
+		dialog.setFileName(fileName);
+		dialog.setOverwrite(true);
+
+		String path = dialog.open();
+		return (path != null) ? new File(path) : null;
+	}
+
 	private void enableControls(boolean enabled, Control... controls) {
 		org.eclipse.swt.graphics.Color disabledColor
 				= getShell().getDisplay().getSystemColor(SWT.COLOR_DARK_GRAY);
@@ -291,6 +368,11 @@ public class AVIOutputSettingsWizardPage extends WizardPage {
 	private void doValidate() {
 		setPageComplete(false);
 
+		if (file == null) {
+			setErrorMessage("出力ファイルが指定されていません。");
+			return;
+		}
+
 		if (!videoEnabled && !audioEnabled) {
 			setErrorMessage("ビデオ出力とオーディオ出力の少なくともどちらか一方は有効にする必要があります。");
 			return;
@@ -309,11 +391,19 @@ public class AVIOutputSettingsWizardPage extends WizardPage {
 //			}
 //		}
 
+		StringBuilder warning = new StringBuilder();
+
+		if (batch && BatchStore.isReserved(file)) {
+			warning.append("同名の出力ファイルでのバッチ登録がすでにあるため、保留状態で登録されます。\n");
+		}
+
+		setMessage(warning.length() > 0 ? warning.toString() : null, IMessageProvider.WARNING);
 		setErrorMessage(null);
 		setPageComplete(true);
 	}
 
 	public void saveDefaults() {
+		batchDefault = batch;
 		videoEnabledDefault = videoEnabled;
 		videoChannelsDefault = videoChannels;
 		colorMatteDefault = colorMatte;
@@ -322,6 +412,14 @@ public class AVIOutputSettingsWizardPage extends WizardPage {
 		audioModeDefault = audioMode;
 	}
 
+	public File getFile() {
+		return file;
+	}
+
+	public boolean isBatch() {
+		return batch;
+	}
+
 	public boolean isVideoEnabled() {
 		return videoEnabled;
 	}
