@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009,2010 Yoshikazu Kuramochi
+ * Copyright (c) 2009-2011 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -51,7 +51,7 @@ public class CompositionWizardPage extends WizardPage {
 	private static final boolean COCOA = SWT.getPlatform().equals("cocoa");
 
 	// TODO この最大値は暫定。グラフィックカード毎に異なるはず。
-	private static final int MAX_SIZE = 8192;
+	public static final int MAX_SIZE = 8192;
 
 	private CompositionSettings _settings;
 
@@ -235,6 +235,7 @@ public class CompositionWizardPage extends WizardPage {
 			_widthRatio = width / gcd;
 			_heightRatio = height / gcd;
 			_freezeRatio.setText(String.format("縦横比を%d:%dに固定", _widthRatio, _heightRatio));
+			_freezeRatio.getParent().layout(new Control[] { _freezeRatio });
 		}
 
 
