@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010 Yoshikazu Kuramochi
+ * Copyright (c) 2010,2011 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -48,7 +48,9 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Text;
 
 import ch.kuramo.javie.api.Color;
+import ch.kuramo.javie.api.Size2i;
 import ch.kuramo.javie.api.Time;
+import ch.kuramo.javie.api.VideoBounds;
 import ch.kuramo.javie.app.widgets.FrameRateComboUtil;
 import ch.kuramo.javie.app.widgets.GridBuilder;
 import ch.kuramo.javie.core.FrameDuration;
@@ -75,6 +77,16 @@ public class MediaOptionsWizardPage extends WizardPage {
 
 	private Text durationText;
 
+	private Text widthText;
+
+	private Text heightText;
+
+	private Button freezeRatioCheck;
+
+	private int widthRatio;
+
+	private int heightRatio;
+
 
 	public MediaOptionsWizardPage(MediaItem mediaItem) {
 		super("MediaInputOptionsWizardPage");
@@ -101,6 +113,8 @@ public class MediaOptionsWizardPage extends WizardPage {
 		gb.size(10, 10).composite(SWT.NULL);
 		createFrameRateAndDurationGroup(gb);
 		gb.size(10, 10).composite(SWT.NULL);
+		createSizeGroup(gb);
+		gb.size(10, 10).composite(SWT.NULL);
 		createMiscGroup(gb);
 
 		Composite grid = gb.getComposite();
@@ -203,25 +217,25 @@ public class MediaOptionsWizardPage extends WizardPage {
 		FillLayout layout = new FillLayout(SWT.HORIZONTAL);
 		layout.marginHeight = 5;
 		group.setLayout(layout);
-		GridBuilder gb2 = new GridBuilder(group, 6, false);
+		GridBuilder gb2 = new GridBuilder(group, 5, false);
 
-		Button soruceFpsButton =	gb2.hSpan(2).hAlign(SWT.LEFT).button(SWT.RADIO, "ファイルのフレームレートを使用:");
-		Label soruceFpsLabel =		gb2.hSpan(4).hAlign(SWT.FILL).hGrab().label(SWT.NULL, "");
+		Button soruceFpsButton =	gb2.hSpan(3).hAlign(SWT.LEFT).button(SWT.RADIO, "ファイルのフレームレートを使用:");
+		Label soruceFpsLabel =		gb2.hSpan(2).hAlign(SWT.FILL).hGrab().label(SWT.NULL, "");
 
 		customFpsButton =			gb2.hSpan(2).hAlign(SWT.LEFT).button(SWT.RADIO, "次のフレームレートに調整:");
 		customFpsCombo =			gb2.hSpan(2).hAlign(SWT.LEFT).combo(SWT.NULL, 0, FrameRateComboUtil.getComboItems(), "");
-		Label framePerSecLabel =	gb2.hSpan(2).hAlign(SWT.FILL).hGrab().label(SWT.NULL, "フレーム／秒");
+		Label framePerSecLabel =	gb2.hSpan(1).hAlign(SWT.FILL).hGrab().label(SWT.NULL, "フレーム／秒");
 
-									gb2.hSpan(6).size(10, 10).composite(SWT.NULL);
+									gb2.hSpan(5).size(10, 10).composite(SWT.NULL);
 
 		Label durationLabel =		gb2.hSpan(1).hAlign(SWT.LEFT).label(SWT.NULL, "デュレーション:");
 		final Label durationLabel2;
 		if (options.isAvailable(Option.DURATION)) {
 			durationText =			gb2.hSpan(2).hAlign(SWT.FILL).text(SWT.BORDER, "");
-			durationLabel2 =		gb2.hSpan(3).hAlign(SWT.FILL).hGrab().label(SWT.NULL, "");
+			durationLabel2 =		gb2.hSpan(2).hAlign(SWT.FILL).hGrab().label(SWT.NULL, "");
 		} else {
 			durationText =			null;
-			durationLabel2 =		gb2.hSpan(5).hAlign(SWT.FILL).hGrab().label(SWT.NULL, "");
+			durationLabel2 =		gb2.hSpan(4).hAlign(SWT.FILL).hGrab().label(SWT.NULL, "");
 		}
 
 		Time soruceFrameDuration = source.getVideoFrameDuration(null);
@@ -293,6 +307,56 @@ public class MediaOptionsWizardPage extends WizardPage {
 		grid2.setTabList(gb2.getTabList());
 	}
 
+	private void createSizeGroup(GridBuilder gb) {
+		Group group = gb.hAlign(SWT.FILL).hGrab().group(SWT.NONE, "サイズ");
+		FillLayout layout = new FillLayout(SWT.HORIZONTAL);
+		layout.marginHeight = 5;
+		group.setLayout(layout);
+		GridBuilder gb2 = new GridBuilder(group, 3, false);
+
+		VideoBounds bounds = source.getVideoFrameBounds(options);
+
+		if (options.isAvailable(Option.SIZE)) {
+								gb2.hSpan(1).hAlign(SWT.RIGHT).label(SWT.NULL, "幅:");
+			widthText =			gb2.hSpan(1).hAlign(SWT.FILL).width(70)
+										.text(SWT.BORDER, String.valueOf(bounds.width));
+			freezeRatioCheck =	gb2.span(1, 2).hAlign(SWT.LEFT).hGrab().button(SWT.CHECK, "縦横比を固定");
+	
+								gb2.hSpan(1).hAlign(SWT.RIGHT).label(SWT.NULL, "高さ:");
+			heightText =		gb2.hSpan(1).hAlign(SWT.FILL).width(70).tabAfter(widthText)
+										.text(SWT.BORDER, String.valueOf(bounds.height));
+
+			final ModifyListener modifyListener = new ModifyListener() {
+				public void modifyText(ModifyEvent e) {
+					updateSize((Control)e.widget, this);
+					doValidate();
+				}
+			};
+
+			widthText.addModifyListener(modifyListener);
+			heightText.addModifyListener(modifyListener);
+
+			freezeRatioCheck.addSelectionListener(new SelectionAdapter() {
+				public void widgetSelected(SelectionEvent e) {
+					updateSize(freezeRatioCheck, modifyListener);
+					doValidate();	// FIXME この doValidate は不要なのでは？
+				}
+			});
+
+			updateSize(null, modifyListener);
+
+		} else {
+			Label widthLabel1 =		gb2.hSpan(1).hAlign(SWT.RIGHT).label(SWT.NULL, "幅:");
+			Label widthLabel2 =		gb2.hSpan(2).hAlign(SWT.LEFT).label(SWT.NULL, String.valueOf(bounds.width));
+			Label heightLabel1 =	gb2.hSpan(1).hAlign(SWT.RIGHT).label(SWT.NULL, "高さ:");
+			Label heightLabel2 =	gb2.hSpan(2).hAlign(SWT.LEFT).label(SWT.NULL, String.valueOf(bounds.height));
+			enableControls(false, group, widthLabel1, widthLabel2, heightLabel1, heightLabel2);
+		}
+
+		Composite grid2 = gb2.getComposite();
+		grid2.setTabList(gb2.getTabList());
+	}
+
 	private void createMiscGroup(GridBuilder gb) {
 		Group group = gb.hAlign(SWT.FILL).hGrab().group(SWT.NONE, "その他のオプション");
 		FillLayout layout = new FillLayout(SWT.HORIZONTAL);
@@ -391,6 +455,54 @@ public class MediaOptionsWizardPage extends WizardPage {
 		}
 	}
 
+	private void updateSize(Control control, ModifyListener modifyListener) {
+		String wStr = null, hStr = null;
+		int width = 0, height = 0;
+
+		wStr = widthText.getText().trim();
+		try {
+			width = Integer.parseInt(wStr);
+		} catch (NumberFormatException e) {
+			width = 0;
+		}
+
+		hStr = heightText.getText().trim();
+		try {
+			height = Integer.parseInt(hStr);
+		} catch (NumberFormatException e) {
+			height = 0;
+		}
+
+		if (freezeRatioCheck.getSelection()) {
+			if (control == widthText && width > 0) {
+				height = Math.max(1, width * heightRatio / widthRatio);
+				heightText.removeModifyListener(modifyListener);
+				heightText.setText(String.valueOf(height));
+				heightText.addModifyListener(modifyListener);
+			} else if (control == heightText && height > 0) {
+				width = Math.max(1, height * widthRatio / heightRatio);
+				widthText.removeModifyListener(modifyListener);
+				widthText.setText(String.valueOf(width));
+				widthText.addModifyListener(modifyListener);
+			}
+		} else if ((control == null || control == widthText || control == heightText) && width > 0 && height > 0) {
+			int gcd = gcd(width, height);
+			widthRatio = width / gcd;
+			heightRatio = height / gcd;
+			freezeRatioCheck.setText(String.format("縦横比を%d:%dに固定", widthRatio, heightRatio));
+			freezeRatioCheck.getParent().layout(new Control[] { freezeRatioCheck });
+		}
+	}
+
+	private int gcd(int x, int y) {
+		while (y != 0) {
+			int t = x % y;
+			x = y;
+			y = t;
+		}
+		return x;
+	}
+
 	private void doValidate() {
 		setPageComplete(false);
 
@@ -439,6 +551,44 @@ public class MediaOptionsWizardPage extends WizardPage {
 			options.setDuration(Time.fromFrameNumber(frames, frameDuration));
 		}
 
+		if (options.isAvailable(Option.SIZE)) {
+			String wStr = null, hStr = null;
+			int width = 0, height = 0;
+
+			wStr = widthText.getText().trim();
+			try {
+				width = Integer.parseInt(wStr);
+			} catch (NumberFormatException e) {
+				width = 0;
+			}
+
+			hStr = heightText.getText().trim();
+			try {
+				height = Integer.parseInt(hStr);
+			} catch (NumberFormatException e) {
+				height = 0;
+			}
+
+			if (wStr.length() == 0) {
+				setErrorMessage("幅が入力されていません。");
+				return;
+			}
+			if (width < 1 || width > CompositionWizardPage.MAX_SIZE) {
+				setErrorMessage(String.format("幅には1から%dまでの整数を入力してください。", CompositionWizardPage.MAX_SIZE));
+				return;
+			}
+			if (hStr.length() == 0) {
+				setErrorMessage("高さが入力されていません。");
+				return;
+			}
+			if (height < 1 || height > CompositionWizardPage.MAX_SIZE) {
+				setErrorMessage(String.format("高さには1から%dまでの整数を入力してください。", CompositionWizardPage.MAX_SIZE));
+				return;
+			}
+
+			options.setSize(new Size2i(width, height));
+		}
+
 		setErrorMessage(null);
 		setPageComplete(!options.equals(origOptions));
 	}
