@@ -99,7 +99,7 @@ public abstract class AbstractEffect implements Effect {
 		}
 	}
 
-	public Object createExpressionElement(final RenderContext renderContext) {
+	public Object createExpressionElement(final CoreContext context) {
 		InvocationHandler handler = new InvocationHandler() {
 			public Object invoke(Object proxy, Method method, Object[] args) throws Throwable {
 				String name = method.getName();
@@ -115,7 +115,7 @@ public abstract class AbstractEffect implements Effect {
 
 				Object value = pd.get(AbstractEffect.this);
 				if (value instanceof Expressionee) {
-					return renderContext.getExpressionElement((Expressionee) value);
+					return context.getExpressionElement((Expressionee) value);
 				} else {
 					return value;
 				}
