@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009 Yoshikazu Kuramochi
+ * Copyright (c) 2009,2010 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -25,6 +25,6 @@ package ch.kuramo.javie.core;
 
 public interface Expressionee {
 
-	Object createExpressionElement(RenderContext renderContext);
+	Object createExpressionElement(CoreContext context);
 
 }
