@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009,2010 Yoshikazu Kuramochi
+ * Copyright (c) 2009-2011 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -25,6 +25,7 @@ package ch.kuramo.javie.core;
 
 import ch.kuramo.javie.api.BlendMode;
 import ch.kuramo.javie.api.IAudioBuffer;
+import ch.kuramo.javie.api.Quality;
 import ch.kuramo.javie.core.VideoLayerRenderer.GeneralLayerRenderer;
 
 public interface MediaLayer extends TransformableLayer, EffectableLayer {
@@ -71,6 +72,14 @@ public interface MediaLayer extends TransformableLayer, EffectableLayer {
 
 	void setCastsShadows(CastsShadows castsShadows);
 
+	AnimatableInteger getShadowExpansionLeft();
+
+	AnimatableInteger getShadowExpansionTop();
+
+	AnimatableInteger getShadowExpansionRight();
+
+	AnimatableInteger getShadowExpansionBottom();
+
 	AnimatableDouble getLightTransmission();
 
 	boolean isAcceptsShadows();
