@@ -23,12 +23,10 @@
 
 package ch.kuramo.javie.core;
 
-public interface MotionBlur {
+public enum MotionBlur {
 
-	double getShutterAngle();
-
-	double getShutterPhase();
-
-	int getSamples();
+	NONE,
+	TRANSFORM,
+	FULL
 
 }
