@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009,2010 Yoshikazu Kuramochi
+ * Copyright (c) 2009-2011 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -34,6 +34,7 @@ import ch.kuramo.javie.api.ColorMode;
 import ch.kuramo.javie.api.IAudioBuffer;
 import ch.kuramo.javie.api.IObjectArray;
 import ch.kuramo.javie.api.IVideoBuffer;
+import ch.kuramo.javie.api.Quality;
 import ch.kuramo.javie.api.Resolution;
 import ch.kuramo.javie.api.Time;
 import ch.kuramo.javie.api.Vec2d;
@@ -44,6 +45,7 @@ import ch.kuramo.javie.api.services.IVideoRenderSupport;
 import ch.kuramo.javie.core.AbstractAnimatableEnum;
 import ch.kuramo.javie.core.AbstractTransformableLayer;
 import ch.kuramo.javie.core.AnimatableDouble;
+import ch.kuramo.javie.core.AnimatableInteger;
 import ch.kuramo.javie.core.AnimatableVec2d;
 import ch.kuramo.javie.core.CastsShadows;
 import ch.kuramo.javie.core.CoreContext;
@@ -58,7 +60,6 @@ import ch.kuramo.javie.core.MediaLayer;
 import ch.kuramo.javie.core.MotionBlur;
 import ch.kuramo.javie.core.Project;
 import ch.kuramo.javie.core.ProjectDecodeException;
-import ch.kuramo.javie.core.Quality;
 import ch.kuramo.javie.core.TrackMatte;
 import ch.kuramo.javie.core.Util;
 import ch.kuramo.javie.core.VectorMediaInput;
@@ -98,6 +99,14 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 
 	private CastsShadows _castsShadows = CastsShadows.OFF;
 
+	private AnimatableInteger _shadowExpansionLeft = new AnimatableInteger(0, 0, 1000);
+
+	private AnimatableInteger _shadowExpansionTop = new AnimatableInteger(0, 0, 1000);
+
+	private AnimatableInteger _shadowExpansionRight = new AnimatableInteger(0, 0, 1000);
+
+	private AnimatableInteger _shadowExpansionBottom = new AnimatableInteger(0, 0, 1000);
+
 	private AnimatableDouble _lightTransmission = new AnimatableDouble(0d, 0d, 100d);
 
 	private boolean _acceptsShadows = true;
@@ -232,6 +241,42 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 		_castsShadows = castsShadows;
 	}
 
+	public AnimatableInteger getShadowExpansionLeft() {
+		return _shadowExpansionLeft;
+	}
+
+	public void setShadowExpansionLeft(AnimatableInteger shadowExpansionLeft) {
+		shadowExpansionLeft.copyConfigurationFrom(_shadowExpansionLeft);
+		_shadowExpansionLeft = shadowExpansionLeft;
+	}
+
+	public AnimatableInteger getShadowExpansionTop() {
+		return _shadowExpansionTop;
+	}
+
+	public void setShadowExpansionTop(AnimatableInteger shadowExpansionTop) {
+		shadowExpansionTop.copyConfigurationFrom(_shadowExpansionTop);
+		_shadowExpansionTop = shadowExpansionTop;
+	}
+
+	public AnimatableInteger getShadowExpansionRight() {
+		return _shadowExpansionRight;
+	}
+
+	public void setShadowExpansionRight(AnimatableInteger shadowExpansionRight) {
+		shadowExpansionRight.copyConfigurationFrom(_shadowExpansionRight);
+		_shadowExpansionRight = shadowExpansionRight;
+	}
+
+	public AnimatableInteger getShadowExpansionBottom() {
+		return _shadowExpansionBottom;
+	}
+
+	public void setShadowExpansionBottom(AnimatableInteger shadowExpansionBottom) {
+		shadowExpansionBottom.copyConfigurationFrom(_shadowExpansionBottom);
+		_shadowExpansionBottom = shadowExpansionBottom;
+	}
+
 	public AnimatableDouble getLightTransmission() {
 		return _lightTransmission;
 	}
@@ -314,6 +359,10 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 		scope.assignTo(_audioLevels);
 		scope.assignTo(_timeRemap);
 
+		scope.assignTo(_shadowExpansionLeft);
+		scope.assignTo(_shadowExpansionTop);
+		scope.assignTo(_shadowExpansionRight);
+		scope.assignTo(_shadowExpansionBottom);
 		scope.assignTo(_lightTransmission);
 		scope.assignTo(_ambient);
 		scope.assignTo(_diffuse);
@@ -356,18 +405,20 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 			}
 
 			public void multModelViewMatrix(double[] mvMatrix) {
-				_oldSupport.setMatrix(mvMatrix, null);
+				_oldSupport.setMatrix(null, mvMatrix);
 				LayerMatrixUtil.multModelViewMatrix(AbstractMediaLayer.this, _context, _oldSupport);
-				_oldSupport.getMatrix(mvMatrix, null);
+				_oldSupport.getMatrix(null, mvMatrix);
 			}
 
 			public VideoBounds calcBounds(boolean withEffects) {
-				return _vePipeline.getVideoBounds(getEffects(withEffects), inputBoundsOperation);
+				return _vePipeline.getVideoBounds(
+						AbstractMediaLayer.this, getEffects(withEffects), inputBoundsOperation);
 			}
 
 			public IVideoBuffer render(boolean withEffects, boolean frameBlendEnabled) {
-				return _vePipeline.doVideoEffects(getEffects(withEffects), inputBoundsOperation,
-													createInputBufferOperation(frameBlendEnabled));
+				return _vePipeline.doVideoEffects(
+						AbstractMediaLayer.this, getEffects(withEffects), inputBoundsOperation,
+						createInputBufferOperation(frameBlendEnabled));
 			}
 
 			private List<Effect> getEffects(boolean withEffects) {
@@ -409,19 +460,22 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 			}
 
 			public void multModelViewMatrix(double[] mvMatrix) {
-				_oldSupport.setMatrix(mvMatrix, null);
+				_oldSupport.setMatrix(null, mvMatrix);
 				LayerMatrixUtil.multModelViewMatrix(AbstractMediaLayer.this, _context, _oldSupport);
-				_oldSupport.getMatrix(mvMatrix, null);
+				_oldSupport.getMatrix(null, mvMatrix);
 			}
 
 			public VideoBounds calcBounds(boolean withEffects, VideoBounds viewport) {
-				return _vePipeline.getVideoBounds(getEffects(withEffects), createInputBoundsOperation(viewport));
+				return _vePipeline.getVideoBounds(
+						AbstractMediaLayer.this, getEffects(withEffects),
+						createInputBoundsOperation(viewport));
 			}
 
-			public IVideoBuffer render(boolean withEffects, VideoBounds viewport, double[] mvMatrix, double[] prjMatrix) {
-				return _vePipeline.doVideoEffects(getEffects(withEffects),
+			public IVideoBuffer render(boolean withEffects, VideoBounds viewport, double[] prjMatrix, double[] mvMatrix) {
+				return _vePipeline.doVideoEffects(
+						AbstractMediaLayer.this, getEffects(withEffects),
 						createInputBoundsOperation(viewport),
-						createInputBufferOperation(viewport, mvMatrix, prjMatrix));
+						createInputBufferOperation(viewport, prjMatrix, mvMatrix));
 			}
 
 			public IVideoBuffer render() {
@@ -446,7 +500,7 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 			}
 
 			private WrappedOperation<IVideoBuffer> createInputBufferOperation(
-					final VideoBounds bounds, final double[] mvMatrix, final double[] prjMatrix) {
+					final VideoBounds bounds, final double[] prjMatrix, final double[] mvMatrix) {
 
 				return new WrappedOperation<IVideoBuffer>() {
 					public IVideoBuffer execute() {
@@ -456,7 +510,7 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 							rasterizedBuffer.clear();
 
 							VectorMediaInput input = (VectorMediaInput) getMediaInput();
-							input.rasterize(rasterizedBuffer, mvMatrix, prjMatrix, calcVideoMediaTime(input));
+							input.rasterize(rasterizedBuffer, prjMatrix, mvMatrix, calcVideoMediaTime(input));
 
 							IVideoBuffer result = rasterizedBuffer;
 							rasterizedBuffer = null;
@@ -841,7 +895,7 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 			}
 		};
 
-		IAudioBuffer ab = _aePipeline.doAudioEffects(
+		IAudioBuffer ab = _aePipeline.doAudioEffects(AbstractMediaLayer.this,
 				(!rawSource && _effectsEnabled) ? _effects : Collections.<Effect>emptyList(), inputOperation);
 
 		if (!rawSource) {
@@ -895,19 +949,23 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 			super(context);
 		}
 
-		public Object getOpacity()				{ return elem(_opacity); }
-		public Object getAudioLevels()			{ return elem(_audioLevels); }
-		public Object getTimeRemap()			{ return LayerNature.isTimeRemapEnabled(AbstractMediaLayer.this) ? elem(_timeRemap) : null; }
+		public Object getOpacity()					{ return elem(_opacity); }
+		public Object getAudioLevels()				{ return elem(_audioLevels); }
+		public Object getTimeRemap()				{ return LayerNature.isTimeRemapEnabled(AbstractMediaLayer.this) ? elem(_timeRemap) : null; }
 
-		public String getCastsShadows()			{ return _castsShadows.name(); }
-		public Object getLightTransmission()	{ return elem(_lightTransmission); }
-		public boolean isAcceptsShadows()		{ return _acceptsShadows; }
-		public boolean isAcceptsLights()		{ return _acceptsLights; }
-		public Object getAmbient()				{ return elem(_ambient); }
-		public Object getDiffuse()				{ return elem(_diffuse); }
-		public Object getSpecular()				{ return elem(_specular); }
-		public Object getShininess()			{ return elem(_shininess); }
-		public Object getMetal()				{ return elem(_metal); }
+		public String getCastsShadows()				{ return _castsShadows.name(); }
+		public Object getShadowExpansionLeft()		{ return elem(_shadowExpansionLeft); }
+		public Object getShadowExpansionTop()		{ return elem(_shadowExpansionTop); }
+		public Object getShadowExpansionRight()		{ return elem(_shadowExpansionRight); }
+		public Object getShadowExpansionBottom()	{ return elem(_shadowExpansionBottom); }
+		public Object getLightTransmission()		{ return elem(_lightTransmission); }
+		public boolean isAcceptsShadows()			{ return _acceptsShadows; }
+		public boolean isAcceptsLights()			{ return _acceptsLights; }
+		public Object getAmbient()					{ return elem(_ambient); }
+		public Object getDiffuse()					{ return elem(_diffuse); }
+		public Object getSpecular()					{ return elem(_specular); }
+		public Object getShininess()				{ return elem(_shininess); }
+		public Object getMetal()					{ return elem(_metal); }
 
 		public Object effect(int index) {
 			Effect effect = _effects.get(index - 1);
