@@ -35,6 +35,11 @@ import ch.kuramo.javie.core.annotations.ProjectElement;
 @ProjectElement("cameraLayer")
 public class CameraLayerImpl extends AbstractLayer implements CameraLayer {
 
+	static final double DEFAULT_NEAR = 10;
+
+	static final double DEFAULT_FAR = 100000;
+
+
 	private boolean _videoEnabled = true;
 
 	private AnimatableVec3d _pointOfInterest = new AnimatableVec3d(new Vec3d(0, 0, 0));
@@ -51,9 +56,9 @@ public class CameraLayerImpl extends AbstractLayer implements CameraLayer {
 
 	private AnimatableDouble _zoom = new AnimatableDouble(100d, 0d, Double.POSITIVE_INFINITY);
 
-	private AnimatableDouble _near = new AnimatableDouble(1d, 0d, Double.POSITIVE_INFINITY);
+	private AnimatableDouble _near = new AnimatableDouble(DEFAULT_NEAR, 0d, Double.POSITIVE_INFINITY);
 
-	private AnimatableDouble _far = new AnimatableDouble(1000d, 0d, Double.POSITIVE_INFINITY);
+	private AnimatableDouble _far = new AnimatableDouble(DEFAULT_FAR, 0d, Double.POSITIVE_INFINITY);
 
 
 	public boolean isVideoEnabled() {
