@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010 Yoshikazu Kuramochi
+ * Copyright (c) 2010,2011 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -135,8 +135,9 @@ public class ImageSequenceItemImpl extends AbstractItem implements ImageSequence
 	}
 
 	public VideoBounds getPlaceholderBounds() {
-		_placeholderBounds = (_mediaSource != null && _mediaSource.isVideoAvailable())
-					? _mediaSource.getVideoFrameBounds(_mediaOptions) : null;
+		if (_mediaSource != null && _mediaSource.isVideoAvailable()) {
+			_placeholderBounds = _mediaSource.getVideoFrameBounds(_mediaOptions);
+		}
 		return _placeholderBounds;
 	}
 
