@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010 Yoshikazu Kuramochi
+ * Copyright (c) 2010,2011 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -78,4 +78,8 @@ public class AntiAliasSupportProxy implements IAntiAliasSupport {
 		getImpl().antiAlias(width, height, operation);
 	}
 
+	public int getSamples() {
+		return getImpl().getSamples();
+	}
+
 }
