@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010 Yoshikazu Kuramochi
+ * Copyright (c) 2010,2011 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -27,7 +27,9 @@ import java.util.List;
 
 public interface FontList {
 
-	List<Font> list();
+	List<String> listFamilyNames();
+
+	List<Font> getFamily(String familyName);
 
 	Font get(String psName);
 
