@@ -125,9 +125,13 @@ public class JavieCoreModule extends AbstractModule {
 				.to(VideoEffectPipelineImpl.class)
 				.in(Scopes.SINGLETON);
 
+		VideoEffectContextProxy veContext = new VideoEffectContextProxy();
+
 		bind(IVideoEffectContext.class)
-				.to(VideoEffectContextProxy.class)
-				.in(Scopes.SINGLETON);
+				.toInstance(veContext);
+
+		bind(QCIntegrationSupport.class)
+				.toInstance(veContext);
 
 		bind(AudioRenderSupport.class)
 				.to(AudioRenderSupportImpl.class)
