@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009,2010 Yoshikazu Kuramochi
+ * Copyright (c) 2009-2011 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -27,11 +27,10 @@ import ch.kuramo.javie.api.Color;
 import ch.kuramo.javie.api.IVideoBuffer;
 import ch.kuramo.javie.api.Size2i;
 import ch.kuramo.javie.api.Vec3d;
-import ftgl.FTGLfont;
 
 public interface VideoRenderSupport {
 
-	void fillRectCR(IVideoBuffer resultBuffer, double[] mvMatrix, double[] prjMatrix, Size2i size, Color color);
+	void fillRectCR(IVideoBuffer resultBuffer, double[] prjMatrix, double[] mvMatrix, Size2i size, Color color);
 
 
 	void multModelViewMatrix(
@@ -46,15 +45,8 @@ public interface VideoRenderSupport {
 	void multCameraMatrixInverse(
 			Vec3d rotate, Vec3d orientation, Vec3d interest, Vec3d position);
 
-	void getMatrix(double[] mvMatrix, double[] prjMatrix);
+	void getMatrix(double[] prjMatrix, double[] mvMatrix);
 
-	void setMatrix(double[] mvMatrix, double[] prjMatrix);
-
-
-	void renderText(FTGLfont font, Color fillColor, String[] texts, double[][] offsets, IVideoBuffer resultBuffer);
-
-	void renderText(
-			FTGLfont font, Color fillColor, String[] texts, double[][] offsets,
-			IVideoBuffer resultBuffer, double[] mvMatrix, double[] prjMatrix);
+	void setMatrix(double[] prjMatrix, double[] mvMatrix);
 
 }
