@@ -88,7 +88,7 @@ JNIEXPORT jint JNICALL JNI_OnLoad(JavaVM* vm, void* reserved)
 	return JNI_VERSION_1_4;
 }
 
-JNIEXPORT jlongArray JNICALL Java_ch_kuramo_javie_core_internal_WindowsDirectShowInput_openVideo
+JNIEXPORT jlongArray JNICALL Java_ch_kuramo_javie_core_internal_WindowsDirectShowSource_openVideo
   (JNIEnv* env, jobject jthis, jstring jfilename)
 {
 	HRESULT hr;
@@ -110,14 +110,14 @@ JNIEXPORT jlongArray JNICALL Java_ch_kuramo_javie_core_internal_WindowsDirectSho
 		return NULL;
 	}
 
-	jlong buf[5] = { reinterpret_cast<jlong>(videoInput), videoInput->GetWidth(), videoInput->GetHeight(),
-					videoInput->GetFrameCount(), videoInput->GetDuration() };
-	jlongArray result = env->NewLongArray(5);
-	env->SetLongArrayRegion(result, 0, 5, buf);
+	jlong buf[6] = { reinterpret_cast<jlong>(videoInput), videoInput->GetWidth(), videoInput->GetHeight(),
+					videoInput->GetDuration(), videoInput->GetFrameDuration(), videoInput->GetFourCC() };
+	jlongArray result = env->NewLongArray(6);
+	env->SetLongArrayRegion(result, 0, 6, buf);
 	return result;
 }
 
-JNIEXPORT jlongArray JNICALL Java_ch_kuramo_javie_core_internal_WindowsDirectShowInput_openAudio
+JNIEXPORT jlongArray JNICALL Java_ch_kuramo_javie_core_internal_WindowsDirectShowSource_openAudio
   (JNIEnv* env, jobject jthis, jstring jfilename)
 {
 	HRESULT hr;
@@ -147,7 +147,7 @@ JNIEXPORT jlongArray JNICALL Java_ch_kuramo_javie_core_internal_WindowsDirectSho
 	return result;
 }
 
-JNIEXPORT void JNICALL Java_ch_kuramo_javie_core_internal_WindowsDirectShowInput_closeVideo
+JNIEXPORT void JNICALL Java_ch_kuramo_javie_core_internal_WindowsDirectShowSource_closeVideo
   (JNIEnv* env, jobject jthis, jlong videoInputAddress)
 {
 	VideoInput* videoInput = reinterpret_cast<VideoInput*>(videoInputAddress);
@@ -156,7 +156,7 @@ JNIEXPORT void JNICALL Java_ch_kuramo_javie_core_internal_WindowsDirectShowInput
 	CoUninitialize();
 }
 
-JNIEXPORT void JNICALL Java_ch_kuramo_javie_core_internal_WindowsDirectShowInput_closeAudio
+JNIEXPORT void JNICALL Java_ch_kuramo_javie_core_internal_WindowsDirectShowSource_closeAudio
   (JNIEnv* env, jobject jthis, jlong audioInputAddress)
 {
 	AudioInput* audioInput = reinterpret_cast<AudioInput*>(audioInputAddress);
@@ -165,7 +165,7 @@ JNIEXPORT void JNICALL Java_ch_kuramo_javie_core_internal_WindowsDirectShowInput
 	CoUninitialize();
 }
 
-JNIEXPORT jint JNICALL Java_ch_kuramo_javie_core_internal_WindowsDirectShowInput_frameImageAtTime
+JNIEXPORT jint JNICALL Java_ch_kuramo_javie_core_internal_WindowsDirectShowSource_frameImageAtTime
   (JNIEnv* env, jobject jthis, jlong videoInputAddress,
    jlong dsTime, jbyteArray byteArray)
 {
@@ -177,7 +177,7 @@ JNIEXPORT jint JNICALL Java_ch_kuramo_javie_core_internal_WindowsDirectShowInput
 	return hr;
 }
 
-JNIEXPORT jint JNICALL Java_ch_kuramo_javie_core_internal_WindowsDirectShowInput_audioChunkFromTime
+JNIEXPORT jint JNICALL Java_ch_kuramo_javie_core_internal_WindowsDirectShowSource_audioChunkFromTime
   (JNIEnv* env, jobject jthis, jlong audioInputAddress,
    jlong dsTime, jobject byteArrayObj, jint offset, jint size)
 {
