@@ -50,7 +50,7 @@ public class Monochrome {
 
 	@ShaderSource
 	public static final String[] MONOCHROME = {
-		"uniform sampler2DRect texture;",
+		"uniform sampler2D texture;",
 		"uniform vec3 highlight;",
 		"uniform vec3 shadow;",
 		"uniform float blend;",
@@ -59,7 +59,7 @@ public class Monochrome {
 		"",
 		"void main(void)",
 		"{",
-		"	vec4 src = texture2DRect(texture, gl_TexCoord[0].st);",
+		"	vec4 src = texture2D(texture, gl_TexCoord[0].st);",
 		"	float y = (src.a != 0.0) ? dot(src.rgb/src.a, yvec) : 0.0;",
 		"	vec3 rgb = shadow*(1.0-y) + highlight*y;",
 		"	float a = src.a*(1.0-blend);",
@@ -108,8 +108,8 @@ public class Monochrome {
 			return input;
 		}
 
-		Color highlight = context.value(this.highlight).clamp();
-		Color shadow = context.value(this.shadow).clamp();
+		Color highlight = context.value(this.highlight);
+		Color shadow = context.value(this.shadow);
 
 		try {
 			Set<GLUniformData> uniforms = new HashSet<GLUniformData>();
