@@ -130,6 +130,7 @@ public class Rectangle {
 		this.arrayPools = arrayPools;
 		rectangleSamplerProgram = shaders.getProgram(Rectangle.class, "RECTANGLE_SAMPLER");
 		invertSamplerProgram = shaders.getProgram(Rectangle.class, "INVERT_SAMPLER");
+		blendSupport.setProgramsClass(blendSupport.getPremultAndMatteClass(false));
 	}
 
 	private class RectangleParams {
@@ -166,6 +167,9 @@ public class Rectangle {
 			Color color = context.value(Rectangle.this.color);
 			double a = color.a;
 			this.color = new Color(color.r*a, color.g*a, color.b*a, a);
+			// FIXME ここで乗算済みにしているのは不適切かもしれない。
+			// このエフェクト内ではColor.clearに渡すところとシェーダに渡すところがあるが、
+			// Color.clearにはストレート、シェーダには乗算済みで渡す必要がある。
 
 			double thickness = 0;
 			double innerFeather = 0;
