@@ -29,12 +29,14 @@ import ch.kuramo.javie.api.IAnimatableEnum;
 import ch.kuramo.javie.api.IVideoBuffer;
 import ch.kuramo.javie.api.annotations.Effect;
 import ch.kuramo.javie.api.annotations.Property;
+import ch.kuramo.javie.api.annotations.Effect.Categories;
 import ch.kuramo.javie.api.services.IShaderRegistry;
 import ch.kuramo.javie.api.services.IVideoEffectContext;
+import ch.kuramo.javie.api.services.IVideoRenderSupport;
 
 import com.google.inject.Inject;
 
-@Effect(id="ch.kuramo.javie.GreenScreenKey", category=Effect.KEYING)
+@Effect(id="ch.kuramo.javie.GreenScreenKey", category=Categories.KEYING)
 public class GreenScreenKey extends BlueGreenScreenKeyBase {
 
 	@Property(value="30", min="0", max="100")
@@ -51,8 +53,8 @@ public class GreenScreenKey extends BlueGreenScreenKeyBase {
 
 
 	@Inject
-	public GreenScreenKey(IVideoEffectContext context, IShaderRegistry shaders) {
-		super(context, shaders, false);
+	public GreenScreenKey(IVideoEffectContext context, IVideoRenderSupport support, IShaderRegistry shaders) {
+		super(context, support, shaders, false);
 	}
 
 	public IVideoBuffer doVideoEffect() {
