@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010 Yoshikazu Kuramochi
+ * Copyright (c) 2010,2011 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -209,38 +209,26 @@ public class FractalNoise {
 		program = shaders.getProgram(FractalNoise.class, "FRACTAL_NOISE");
 
 		this.blendSupport = blendSupport;
+		blendSupport.setProgramsClass(blendSupport.getPremultAndMatteClass(true));
 		blendSupport.replace(BlendMode.HUE, shaders.getProgram(FractalNoise.class, "HUE"));
 		blendSupport.replace(BlendMode.SATURATION, shaders.getProgram(FractalNoise.class, "SATURATION"));
 	}
 
 	public IVideoBuffer doVideoEffect() {
-		BlendMode blendMode = context.value(this.blendMode);
-		double opacity = context.value(this.opacity) / 100;
-		boolean noBlend = (blendMode == BlendMode.NONE || blendMode == BlendMode.NORMAL) && opacity == 1;
-
-		IVideoBuffer original;
-		VideoBounds bounds;
-
-		if (noBlend) {
-			bounds = context.getPreviousBounds();
-			original = context.createVideoBuffer(bounds);
-		} else {
-			original = context.doPreviousEffect();
-			bounds = original.getBounds();
-		}
-
+		IVideoBuffer original = context.doPreviousEffect();
+		VideoBounds bounds = original.getBounds();
 		if (bounds.isEmpty()) {
 			return original;
 		}
 
 		IVideoBuffer fractal = null;
 		try {
-			if (noBlend) {
-				return doFractalNoise(bounds);
-			} else {
-				fractal = doFractalNoise(bounds);
-				return blendSupport.blend(fractal, original, null, blendMode, opacity, context);
-			}
+			fractal = doFractalNoise(bounds);
+
+			BlendMode blendMode = context.value(this.blendMode);
+			double opacity = context.value(this.opacity) / 100;
+			return blendSupport.blend(fractal, original, null, blendMode, opacity, context);
+
 		} finally {
 			if (original != null) original.dispose();
 			if (fractal != null) fractal.dispose();
@@ -457,7 +445,12 @@ public class FractalNoise {
 		  hue ? "	vec3 newDst3 = set_lum(set_sat(hsl2rgb(vec3(pSrc.r, 1.0, 0.5)), sat(uDst3)), dot(uDst3, lumaVec));"
 			  : "	vec3 newDst3 = set_lum(set_sat(uDst3, pSrc.r), dot(uDst3, lumaVec));",
 				"",
-				"	gl_FragColor = vec4(newDst3*da*sa + pDst3*csa, a);",
+				"	vec4 blend = vec4(newDst3*da*sa + pDst3*csa, a);",
+				"	if (blend.a != 0.0) {",
+				"		gl_FragColor = blend/blend.a * da;",
+				"	} else {",
+				"		gl_FragColor = vec4(0.0);",
+				"	}",
 				"}"
 		};
 	};
