@@ -2,6 +2,7 @@ package ftgl;
 
 import com.sun.jna.Library;
 import com.sun.jna.Native;
+import com.sun.jna.Pointer;
 import com.sun.jna.ptr.DoubleByReference;
 
 public class FTGL {
@@ -75,6 +76,7 @@ public class FTGL {
 	}
 
 	public synchronized static float ftglGetFontAdvance(FTGLfont font, String string) {
+		lib.ftVectoriserMakeMesh(font, string, FTVectoriserMakeMeshCallback.CALLBACK);
 		return lib.ftglGetFontAdvance(font, string);
 	}
 
@@ -83,6 +85,7 @@ public class FTGL {
 	}
 
 	public synchronized static void ftglGetFontBBox(FTGLfont font, String string, int len, float[] bounds) {
+		lib.ftVectoriserMakeMesh(font, string, FTVectoriserMakeMeshCallback.CALLBACK);
 		lib.ftglGetFontBBox(font, string, len, bounds);
 	}
 
@@ -147,6 +150,7 @@ public class FTGL {
 	}
 
 	public synchronized static void ftglRenderFont(FTGLfont font, String string, int mode) {
+		lib.ftVectoriserMakeMesh(font, string, FTVectoriserMakeMeshCallback.CALLBACK);
 		lib.ftglRenderFont(font, string, mode);
 	}
 
@@ -203,6 +207,55 @@ public class FTGL {
 	}
 
 
+	////////////////////////////////////////////////////////////////////////////////
+	// FTVectoriserMakeMesh                                                       //
+	////////////////////////////////////////////////////////////////////////////////
+
+	public static void ftContour_Point(Pointer p, int index, double[] out) {
+		lib.ftContour_Point(p, index, out);
+	}
+
+	public static void ftContour_FrontPoint(Pointer p, int index, double[] out) {
+		lib.ftContour_FrontPoint(p, index, out);
+	}
+
+	public static void ftContour_BackPoint(Pointer p, int index, double[] out) {
+		lib.ftContour_BackPoint(p, index, out);
+	}
+
+	public static void ftContour_buildFrontOutset(Pointer p, float outset) {
+		lib.ftContour_buildFrontOutset(p, outset);
+	}
+
+	public static void ftContour_buildBackOutset(Pointer p, float outset) {
+		lib.ftContour_buildBackOutset(p, outset);
+	}
+
+	public static int ftContour_PointCount(Pointer p) {
+		return lib.ftContour_PointCount(p);
+	}
+
+	public static void ftMesh_AddPoint(Pointer p, double x, double y, double z) {
+		lib.ftMesh_AddPoint(p, x, y, z);
+	}
+
+	public static void ftMesh_Combine(Pointer p, double x, double y, double z, double[] out) {
+		lib.ftMesh_Combine(p, x, y, z, out);
+	}
+
+	public static void ftMesh_Begin(Pointer p, int meshType) {
+		lib.ftMesh_Begin(p, meshType);
+	}
+
+	public static void ftMesh_End(Pointer p) {
+		lib.ftMesh_End(p);
+	}
+
+	public static void ftMesh_Error(Pointer p, int e) {
+		lib.ftMesh_Error(p, e);
+	}
+
+
 	////////////////////////////////////////////////////////////////////////////////
 	// freetype                                                                   //
 	////////////////////////////////////////////////////////////////////////////////
@@ -229,6 +282,14 @@ public class FTGL {
 		return lib.ft_Get_Sfnt_Name(face, idx, sfntName);
 	}
 
+	public static TT_Header ft_Get_Sfnt_Header_Table(FT_Face face) {
+		return lib.ft_Get_Sfnt_Header_Table(face);
+	}
+
+	public static TT_OS2 ft_Get_Sfnt_OS2_Table(FT_Face face) {
+		return lib.ft_Get_Sfnt_OS2_Table(face);
+	}
+
 	public static int ft_Init_FreeType(FT_Library[] alibrary) {
 		return lib.ft_Init_FreeType(alibrary);
 	}
@@ -667,6 +728,25 @@ interface FTGLLib extends Library {
 
 
 
+	////////////////////////////////////////////////////////////////////////////////
+	// FTVectoriserMakeMesh                                                       //
+	////////////////////////////////////////////////////////////////////////////////
+
+	void ftVectoriserMakeMesh(FTGLfont font, String string, FTVectoriserMakeMeshCallback callback);
+	void ftContour_Point(Pointer p, int index, double[] out);
+	void ftContour_FrontPoint(Pointer p, int index, double[] out);
+	void ftContour_BackPoint(Pointer p, int index, double[] out);
+	void ftContour_buildFrontOutset(Pointer p, float outset);
+	void ftContour_buildBackOutset(Pointer p, float outset);
+	int ftContour_PointCount(Pointer p);
+	void ftMesh_AddPoint(Pointer p, double x, double y, double z);
+	void ftMesh_Combine(Pointer p, double x, double y, double z, double[] out);
+	void ftMesh_Begin(Pointer p, int meshType);
+	void ftMesh_End(Pointer p);
+	void ftMesh_Error(Pointer p, int e);
+
+
+
 	////////////////////////////////////////////////////////////////////////////////
 	// freetype function wrappers                                                 //
 	////////////////////////////////////////////////////////////////////////////////
@@ -677,5 +757,7 @@ interface FTGLLib extends Library {
 	int ft_Done_Face(FT_Face face);
 	int ft_Get_Sfnt_Name_Count(FT_Face face);
 	int ft_Get_Sfnt_Name(FT_Face face, int idx, FT_SfntName[] sfntName);
+	TT_Header ft_Get_Sfnt_Header_Table(FT_Face face);
+	TT_OS2 ft_Get_Sfnt_OS2_Table(FT_Face face);
 
 }
